Documentation
¶
Overview ¶
Package agent defines agent functionnality
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExecuteConfigInstruction ¶
ExecuteConfigInstruction executes a config instruction and either sends an instruction to the agent or performs the instruction directly
func UnregisterCmd ¶
UnregisterCmd provides unregister cli command
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.